@@ -1,11 +1,11 @@
 #' Support Vector Machine Models
-#' 
+#'
 #' Fits the well known C-svc, nu-svc, (classification) one-class-svc (novelty)
 #' eps-svr, nu-svr (regression) formulations along with native multi-class
 #' classification formulations and the bound-constraint SVM formulations.
-#' 
+#'
 #' @rdname SVMModel
-#' 
+#'
 #' @param scaled logical vector indicating the variables to be scaled.
 #' @param type type of support vector machine.
 #' @param kernel kernel function used in training and predicting.
@@ -27,7 +27,7 @@
 #'   modify the data itself.
 #' @param offset offset used in polynomial and hyperbolic tangent kernels.
 #' @param ... arguments passed to \code{SVMModel}.
-#' 
+#'
 #' @details
 #' \describe{
 #'   \item{Response Types:}{\code{factor}, \code{numeric}}
@@ -42,29 +42,29 @@
 #'     }
 #'   }
 #' }
-#' 
+#'
 #' Arguments \code{kernel} and \code{kpar} are automatically set by the
 #' kernel-specific constructor functions.
 #' Default values for the \code{NULL} arguments and further model details can be
 #' found in the source link below.
-#' 
+#'
 #' @return \code{MLModel} class object.
-#' 
+#'
 #' @seealso \code{\link[kernlab]{ksvm}}, \code{\link{fit}},
-#' \code{\link{resample}}, \code{\link{tune}}
+#' \code{\link{resample}}
 #'
 #' @examples
 #' fit(sale_amount ~ ., data = ICHomes, model = SVMRadialModel)
-#' 
+#'
 SVMModel <- function(scaled = TRUE, type = NULL,
                      kernel = c("rbfdot", "polydot", "vanilladot", "tanhdot",
                                 "laplacedot", "besseldot", "anovadot",
                                 "splinedot"),
                      kpar = "automatic", C = 1, nu = 0.2, epsilon = 0.1,
                      cache = 40, tol = 0.001, shrinking = TRUE) {
-  
+
   kernel <- match.arg(kernel)
-  
+
   MLModel(
     name = "SVMModel",
     label = "Support Vector Machines",
@@ -79,21 +79,21 @@ SVMModel <- function(scaled = TRUE, type = NULL,
                                        prob.model = TRUE, ...),
                matrix = kernlab::ksvm(x, y, prob.model = TRUE, ...))
     },
-    predict = function(object, newdata, fitbits, ...) {
+    predict = function(object, newdata, model, ...) {
       newdata <- as.data.frame(newdata)
       kernlab::predict(object, newdata = newdata,
-                       type = ifelse(is.factor(response(fitbits)),
+                       type = ifelse(is.factor(response(model)),
                                      "probabilities", "response"))
     }
   )
-  
+
 }
 
 MLModelFunction(SVMModel) <- NULL
 
 
 #' @rdname SVMModel
-#' 
+#'
 SVMANOVAModel <- function(sigma = 1, degree = 1, ...) {
   .SVMModel("SVMANOVAModel", "Support Vector Machines (ANOVA)",
             "anovadot", environment(), ...)
@@ -103,7 +103,7 @@ MLModelFunction(SVMANOVAModel) <- NULL
 
 
 #' @rdname SVMModel
-#' 
+#'
 SVMBesselModel <- function(sigma = 1, order = 1, degree = 1, ...) {
   .SVMModel("SVMBesselModel", "Support Vector Machines (Bessel)",
             "besseldot", environment(), ...)
@@ -113,7 +113,7 @@ MLModelFunction(SVMBesselModel) <- NULL
 
 
 #' @rdname SVMModel
-#' 
+#'
 SVMLaplaceModel <- function(sigma = NULL, ...) {
   .SVMModel("SVMLaplaceModel", "Support Vector Machines (Laplace)",
             "laplacedot", environment(), ...)
@@ -123,7 +123,7 @@ MLModelFunction(SVMLaplaceModel) <- NULL
 
 
 #' @rdname SVMModel
-#' 
+#'
 SVMLinearModel <- function(...) {
   .SVMModel("SVMLinearModel", "Support Vector Machines (Linear)",
             "vanilladot", environment(), ...)
@@ -133,7 +133,7 @@ MLModelFunction(SVMLinearModel) <- NULL
 
 
 #' @rdname SVMModel
-#' 
+#'
 SVMPolyModel <- function(degree = 1, scale = 1, offset = 1, ...) {
   .SVMModel("SVMPolyModel", "Support Vector Machines (Poly)",
             "polydot", environment(), ...)
@@ -143,7 +143,7 @@ MLModelFunction(SVMPolyModel) <- NULL
 
 
 #' @rdname SVMModel
-#' 
+#'
 SVMRadialModel <- function(sigma = NULL, ...) {
   .SVMModel("SVMRadialModel", "Support Vector Machines (Radial)",
             "rbfdot", environment(), ...)
@@ -153,7 +153,7 @@ MLModelFunction(SVMRadialModel) <- NULL
 
 
 #' @rdname SVMModel
-#' 
+#'
 SVMSplineModel <- function(...) {
   .SVMModel("SVMSplineModel", "Support Vector Machines (Spline)",
             "splinedot", environment(), ...)
@@ -163,7 +163,7 @@ MLModelFunction(SVMSplineModel) <- NULL
 
 
 #' @rdname SVMModel
-#' 
+#'
 SVMTanhModel <- function(scale = 1, offset = 1, ...) {
   .SVMModel("SVMTanhModel", "Support Vector Machines (Tanh)",
             "tanhdot", environment(), ...)
@@ -184,10 +184,10 @@ MLModelFunction(SVMTanhModel) <- NULL
   model <- do.call(SVMModel, args, quote = TRUE)
   model@name <- name
   model@label <- label
-  
+
   scaled <- model@params$scaled
   if (!is.logical(scaled)) scaled <- TRUE
-  
+
   params <- switch(kernel,
                    "anovadot" = list(C = NULL, degree = NULL),
                    "besseldot" = list(C = NULL, order = NULL,
@@ -196,7 +196,7 @@ MLModelFunction(SVMTanhModel) <- NULL
                    "polydot" = list(C = NULL, degree = NULL, scale = NULL),
                    "rbfdot" = list(C = NULL, sigma = NULL),
                    "vanilladot" = list(C = NULL))
-  
+
   if (length(params)) {
     model@grid <- function(x, length, ...) {
       params %>%
